
class BattleRoyaleUT extends DeathMatchPlus;

#exec AUDIO IMPORT NAME=uWon FILE=Sounds\uWon.wav Group=Announcer

var config bool bHighDetailGhosts;
var() int Lives;
var int TotalKills, NumGhosts;
var localized string AltStartupMessage;
var PlayerPawn LocalPlayer;
var bool bSlowTime;
var Pawn LastKilled;  
var MediaLoader ML;
var BRUTGameReplicationInfo GRI;

function PreBeginPlay()
{
	Super.PreBeginPlay();
   //Added it's own mutator class to allow easy changes
   Level.Game.BaseMutator.AddMutator(Level.Spawn(class'BRUT')); 

   //Spawn the media loader for the end game announcer
	ML=spawn(class'MediaLoader');
	ML.LoadSounds();
}

//Need to clean up the gamegoal message
function PlayStartUpMessage(PlayerPawn NewPlayer)
{
   local int i;

   NewPlayer.ClearProgressMessages();
   NewPlayer.SetProgressMessage(GameName, i++);

   if (fraglimit > 0)
      NewPlayer.SetProgressMessage(GameGoal, i++);

   if (Level.NetMode == NM_Standalone)
      NewPlayer.SetProgressMessage(SingleWaitingMessage, i++);
   else if (bRequireReady)
      NewPlayer.SetProgressMessage(TourneyMessage, i++);
}

event InitGame(string Options, out string Error)
{
   local string InOpt;

   Super.InitGame(Options, Error);

   RemainingTime = 60 * TimeLimit;
   SetGameSpeed(GameSpeed);
   FragLimit = 1;
   TimeLimit = GetIntOption(Options, "TimeLimit", TimeLimit);
   MaxCommanders = GetIntOption(Options, "MaxCommanders", MaxCommanders);

   InOpt = ParseOption(Options, "CoopWeaponMode");
   if (InOpt != "")
      bCoopWeaponMode = bool(InOpt);

   IDnum = -1;
   IDnum = GetIntOption(Options, "Tournament", IDnum);
   if (IDnum > 0)
   {
      bRatedGame = true;
      TimeLimit = 0;
      RemainingTime = 0;
   }
   if (bTournament)
   {
      bRequireReady = true;
      CheckReady();
   }
   if (Level.NetMode == NM_StandAlone)
   {
      bRequireReady = true;
      CountDown = 1;
   }
   if (!bRequireReady && (Level.NetMode != NM_Standalone))
   {
      bRequireReady = true;
      bNetReady = true;
   }

   Lives = Fraglimit;
}

function float GameThreatAdd(Bot aBot, Pawn Other)
{
   if (!Other.bIsPlayer)
      return 0;
   else
      return 0.1 * Other.PlayerReplicationInfo.Score;
}

event playerpawn Login(string Portal,string Options,out string Error,class<playerpawn> SpawnClass)
{
   local playerpawn NewPlayer;
   local Pawn P;

   // if more than 15% of the game is over, must join as spectator
   if (TotalKills > 0.15 * (NumPlayers + NumBots) * Lives)
   {
      bDisallowOverride = true;
      SpawnClass = class'CHSpectator';
      if ((NumSpectators >= MaxSpectators) && ((Level.NetMode != NM_ListenServer) || (NumPlayers > 0)))
      {
         MaxSpectators++;
      }
   }
   NewPlayer = Super.Login(Portal, Options, Error, SpawnClass);

   if ((NewPlayer != None) && !NewPlayer.IsA('Spectator') && !NewPlayer.IsA('Commander'))
      NewPlayer.PlayerReplicationInfo.Score = Lives;

   return NewPlayer;
}

event PostLogin(playerpawn NewPlayer)
{
   if(NewPlayer.Player != None && Viewport(NewPlayer.Player) != None)
      LocalPlayer = NewPlayer;

   if ((TotalKills > 0.15 * (NumPlayers + NumBots) * Lives) && NewPlayer.IsA('CHSpectator'))
      GameName = AltStartupMessage;
   Super.PostLogin(NewPlayer);
   GameName = Default.GameName;
}

function bool NeedPlayers()
{
   if (bGameEnded || (TotalKills > 0.15 * (NumPlayers + NumBots) * Lives))
      return false;
   return (NumPlayers + NumBots < MinPlayers);
}

function bool RestartPlayer(pawn aPlayer)
{
   local NavigationPoint startSpot;
   local bool foundStart;
   local Pawn P;

   if(bRestartLevel && Level.NetMode!=NM_DedicatedServer && Level.NetMode!=NM_ListenServer)
      return true;

   if (aPlayer.PlayerReplicationInfo.Score < 1)
   {
      BroadcastLocalizedMessage(class'BRUTOutMessage', 0, aPlayer.PlayerReplicationInfo);
      For (P=Level.PawnList; P!=None; P=P.NextPawn)
         if (P.bIsPlayer && (P.PlayerReplicationInfo.Score >= 1))
            P.PlayerReplicationInfo.Score += 0.00001;
      if (aPlayer.IsA('Bot'))
      {
         aPlayer.PlayerReplicationInfo.bIsSpectator = true;
         aPlayer.PlayerReplicationInfo.bWaitingPlayer = true;
         aPlayer.GotoState('GameEnded');
         return false; // bots don't respawn when ghosts
      }
   }
   startSpot = FindPlayerStart(None, 255);
   if(startSpot == None)
      return false;
   foundStart = aPlayer.SetLocation(startSpot.Location);
   if(foundStart)
   {
      startSpot.PlayTeleportEffect(aPlayer, true);
      aPlayer.SetRotation(startSpot.Rotation);
      aPlayer.ViewRotation = aPlayer.Rotation;
      aPlayer.Acceleration = vect(0,0,0);
      aPlayer.Velocity = vect(0,0,0);
      aPlayer.Health = aPlayer.Default.Health;
      aPlayer.ClientSetRotation(startSpot.Rotation);
      aPlayer.bHidden = false;
      aPlayer.SoundDampening = aPlayer.Default.SoundDampening;
      if (aPlayer.PlayerReplicationInfo.Score < 1)
      {
         // This guy is a ghost.  Add a visual effect.
         if (bHighDetailGhosts)
         {
            aPlayer.Style = STY_Translucent;
            aPlayer.ScaleGlow = 0.5;
         }
         else
            aPlayer.bHidden = true;
         aPlayer.PlayerRestartState = 'PlayerSpectating';
      }
      else
      {
         aPlayer.SetCollision(true, true, true);
         AddDefaultInventory(aPlayer);
      }
   }
   return foundStart;
}

function Logout(pawn Exiting)
{
   Super.Logout(Exiting);

   if(LocalPlayer == None || Exiting != LocalPlayer)
   	CheckEndGame();
}

function Killed(pawn killer, pawn Other, name damageType)
{
   local int OldFragLimit;

   OldFragLimit = FragLimit;
   FragLimit = 0;

   if (Other.bIsPlayer)
      TotalKills++;

	//Keep track of last person killed
   LastKilled = Other;

   Super.Killed(Killer, Other, damageType);
   FragLimit = OldFragLimit;
   CheckEndGame();
}

function CheckEndGame()
{
   local Pawn PawnLink;
   local int StillPlaying;
   local bool bStillHuman;
   local bot B, D, BB;
   local actor A;

   if (bGameEnded)
      return;

   // Check to see if everyone is a ghost.
   NumGhosts = 0;
   for (PawnLink=Level.PawnList; PawnLink!=None; PawnLink=PawnLink.nextPawn)
      if (PawnLink.bIsPlayer)
      {
         if (PawnLink.PlayerReplicationInfo.Score < 1)
            NumGhosts++;
         else
         {
            if (PawnLink.IsA('PlayerPawn'))
               bStillHuman = true;
            StillPlaying++;
         }
      }

   // End the game if there is only one man standing.
   if (StillPlaying < 2)
   {
   	if (FRand() < 0.65)
   	{
   		BRUTGameReplicationInfo(GameReplicationInfo).bSlowTime=True;
   		SetKillCam();
   	}
   	else
   	{
      	EndGame("BRUT");
      	foreach AllActors(class'Bot',BB) //added check to stop bots respawning
        		BB.GotoState('GameEnded');
      }
   }
   else if (!bStillHuman)
   {
      // no humans left - get bots to be more aggressive and finish up
      for (PawnLink=Level.PawnList; PawnLink!=None; PawnLink=PawnLink.NextPawn)
      {
         B = Bot(PawnLink);
         if (B != None)
         {
            B.CampingRate = 0;
            B.Aggressiveness += 5.0;
            if (D == None)
               D = B;
            else if (B.Enemy == None)
               B.SetEnemy(D);
         }
      }
   }
}

function SetKillCam()
{
   local pawn P;
   local PlayerPawn Player;

   for (P=Level.PawnList; P!=None; P=P.nextPawn)
   {
      Player = PlayerPawn(P);
      if (Player != None)
      {
         Player.bBehindView = true;
         Player.ViewTarget = LastKilled;
      }
   }
}

function ScoreKill(pawn Killer, pawn Other)
{
   Other.DieCount++;
   if (Other.PlayerReplicationInfo.Score > 0)
      Other.PlayerReplicationInfo.Score -= 1;
   if((killer != Other) && (killer != None))
      killer.killCount++;
   BaseMutator.ScoreKill(Killer, Other);
}

function bool PickupQuery(Pawn Other, Inventory item)
{
   if (Other.PlayerReplicationInfo.Score < 1)
      return false;

   return Super.PickupQuery(Other, item);
}
function byte AssessBotAttitude(Bot aBot, Pawn Other)
{
   local float Adjust;

   if (aBot.bNovice)
      Adjust = -0.2;
   else
      Adjust = -0.2 - 0.1 * aBot.Skill;
   if (Other.bIsPlayer && (Other.PlayerReplicationInfo.Score < 1))
      return 2; //bots ignore ghosts
   else if (aBot.bKamikaze)
      return 1;
   else if (Other.IsA('TeamCannon') || (aBot.RelativeStrength(Other) > aBot.Aggressiveness - Adjust))
      return 0;
   else
      return 1;
}

function ModifyBehaviour(Bot NewBot)
{
   // Set the Bot's Lives
   NewBot.PlayerReplicationInfo.Score = Lives;
   NewBot.CampingRate += FRand();
}

function bool OneOnOne()
{
   return (NumPlayers + NumBots - NumGhosts == 2);
}

function bool SetEndCams(string Reason)
{
   local pawn P, Best;
   local PlayerPawn Player;
   local Bot NonPlayer;
   local sound Announcement;
   local int numAnnounce;
   local Vector X;
   local	int hs;

   // find individual winner
   for (P=Level.PawnList; P!=None; P=P.nextPawn)
      if (P.bIsPlayer && !P.IsA('Spectator') && ((Best == None) || (P.PlayerReplicationInfo.Score > Best.PlayerReplicationInfo.Score)))
         Best = P;

   // check for tie
   for (P=Level.PawnList; P!=None; P=P.nextPawn)
      if (P.bIsPlayer && (Best != P) && (P.PlayerReplicationInfo.Score == Best.PlayerReplicationInfo.Score))
      {
         BroadcastLocalizedMessage(DMMessageClass, 0);
         return false;
      }

   EndTime = Level.TimeSeconds + 3.0;
   GameReplicationInfo.GameEndedComments = GameEndedMessage;

   for (P=Level.PawnList; P!=None; P=P.nextPawn)
   {
      NonPlayer = Bot(P);
      if (NonPlayer != None)
      {
			if (NonPlayer != Best)  //force gib the final loser for visual effect
         	NonPlayer.TakeDamage(1000, Pawn(Owner), Location, 60000 * X, 'jolted');
      }
   }

   for (P=Level.PawnList; P!=None; P=P.nextPawn)
   {
      Player = PlayerPawn(P);
      if (Player != None)
      {
      	if (!bTutorialGame)
         {
          	if(ML.sndAnnouncerSoundSize > 0) //grab a random announcer if configured
          	{
					hs=rand(ML.sndAnnouncerSoundSize);
         		Player.ClientPlaySound(ML.sndAnnouncerSound[hs], true, true);
         	}
         	else
            	Player.ClientPlaySound(sound'uWon', true, true);
            	
            Player.bBehindView = true;
            if (Player == Best)
               Player.ViewTarget = None;
            else
               Player.ViewTarget = Best;

            Player.ClientGameEnded();
        	}
        	P.GotoState('GameEnded');
      }
   }

   CalcEndStats();
   return true;
}

defaultproperties
{
	HUDType=Class'BRUTHUD'
	FragLimit=1
	gamegoal="Kill everyone to win"
   bAlwaysForceRespawn=True
   StartMessage="There can be only one!"
   GameEndedMessage="YOU ARE THE LAST PERSON STANDING!"
   ScoreBoardType=Class'BRUTScoreBoard'
   RulesMenuType="UTMenu.UTLMSRulesSC"
   BeaconName="DM"
   GameName="BattleRoyale UTUS"
	MutatorClass=Class'DMNoLogMutator'
	GameReplicationInfoClass=Class'BRUTGameReplicationInfo'
}

